
var bSwitchViews = false;
				
var bStartTableView = false
				
var currModelId = "ID159584";
							
var currModelVersion = "";
						
var currModelName = "Governance Framework implementation";
			
var currModelType = "IT Service Process Architecture";
			 
var currMailAddress = "";
			
var bModInfoWindow = false;
				
var bPrintOne = false;				
				
var bPrintTwo = false;
				
var modInfo = new Array();
		
var overviewimage = new Image();
			
var modelimage68 = new Image();
			
var modelimage45 = new Image();
			
var modelimage90 = new Image();
			
if (!parent.header)
{
	var strPath = top.window.location.href;
	top.location.href= strPath.substring(0, strPath.lastIndexOf("/") + 1) + "../index.html?id=" + currModelId;
}
else
{
	var z = top.header.iZoom;
	checkLoadTableView();
}

function checkLoadTableView()
{
  if (bStartTableView && !parent.header.bModelLoaded)
  {
    top.model.location.href = "../" + currModelId + "/" + currModelId + "t.html"
  }
  else
  {
		overviewimage.src = "../overview/ID159584.png";
			
		if (z == 68) { modelimage68.src = "../images/ado67.png"; }
		else { window.setTimeout("eval(\"modelimage68.src = '../images/ado67.png'\");", 1000); }
			
		if (z == 45) { modelimage45.src = "../images/ado68.png"; }
		else { window.setTimeout("eval(\"modelimage45.src = '../images/ado68.png'\");", 1000); }
			
		if (z == 90) { modelimage90.src = "../images/ado69.png"; }
		else { window.setTimeout("eval(\"modelimage90.src = '../images/ado69.png'\");", 1000); }
			
	}
	parent.header.bModelLoaded = true;
}

function actualizeImageArea()
{
	prepareImageMap();
						
createImageArea(32.39, 25.2, 32.89, 25.7, "ID159664", "ID163569", "", "", true);
								
createImageArea(21.3, 17.7, 21.8, 18.2, "ID159658", "ID159562", "", "", true);
								
createImageArea(21.3, 13.7, 21.8, 14.2, "ID159655", "ID158865", "", "", true);
								
createImageArea(42.3, 21.2, 42.8, 21.7, "ID159631", "ID158976", "", "", true);
								
createImageArea(1.3, 21.27, 1.8, 21.77, "ID159625", "ID162238", "", "", true);
								
createImageArea(20.37, 25.2, 20.87, 25.7, "ID159622", "ID161522", "", "", true);
								
createImageArea(26.3, 25.58, 26.8, 26.08, "ID159619", "ID161440", "", "", true);
								
createImageArea(14.38, 25.2, 14.88, 25.7, "ID159610", "ID161471", "", "", true);
								
createImageArea(35.88, 5.7, 36.38, 6.2, "ID159604", "ID161632", "", "", true);
								
createImageArea(31.38, 5.7, 31.88, 6.2, "ID159601", "ID161585", "", "", true);
								
createImageArea(26.3, 8.19, 26.8, 8.69, "ID159598", "ID160596", "", "", true);
								
createImageArea(21.38, 5.7, 21.88, 6.2, "ID159595", "ID160386", "", "", true);
								
createImageArea(16.88, 5.7, 17.38, 6.2, "ID159592", "ID160356", "", "", true);
								
createImageArea(12.37, 5.7, 12.87, 6.2, "ID159589", "ID160296", "", "", true);
								
createImageArea(7.87, 5.7, 8.370000000000001, 6.2, "ID159586", "ID160135", "", "", true);
				
	createImageArea(32.39, 25.2, 35.41, 27.8, "ID159664", "ID159584", "ID159664", "", false);
					
	createImageArea(21.299999999999997, 17.7, 24.5, 20.3, "ID159658", "ID159584", "ID159658", "", false);
					
	createImageArea(21.299999999999997, 13.7, 24.5, 16.3, "ID159655", "ID159584", "ID159655", "", false);
					
	createImageArea(42.3, 21.2, 45.5, 23.8, "ID159631", "ID159584", "ID159631", "", false);
					
	createImageArea(1.2999999999999998, 21.27, 4.5, 23.77, "ID159625", "ID159584", "ID159625", "", false);
					
	createImageArea(20.369999999999997, 25.2, 23.43, 27.8, "ID159622", "ID159584", "ID159622", "", false);
					
	createImageArea(26.299999999999997, 25.58, 29.5, 32.08, "ID159619", "ID159584", "ID159619", "", false);
					
	createImageArea(14.375, 25.2, 17.425, 27.8, "ID159610", "ID159584", "ID159610", "", false);
					
	createImageArea(35.875, 5.7, 38.925, 8.3, "ID159604", "ID159584", "ID159604", "", false);
					
	createImageArea(31.375, 5.7, 34.425, 8.3, "ID159601", "ID159584", "ID159601", "", false);
					
	createImageArea(26.299999999999997, 8.19, 29.5, 20.189999999999998, "ID159598", "ID159584", "ID159598", "", false);
					
	createImageArea(21.375, 5.7, 24.424999999999997, 8.3, "ID159595", "ID159584", "ID159595", "", false);
					
	createImageArea(16.875, 5.7, 19.924999999999997, 8.3, "ID159592", "ID159584", "ID159592", "", false);
					
	createImageArea(12.370000000000001, 5.7, 15.43, 8.3, "ID159589", "ID159584", "ID159589", "", false);
					
	createImageArea(7.87, 5.7, 10.93, 8.3, "ID159586", "ID159584", "ID159586", "", false);
					
	createImageArea(25.5, 24.5, 30.5, 32.5, "ID159640", "ID159584", "ID159640", "", false);
					
	createImageArea(7.5, 29.5, 39.5, 33, "ID159661", "ID159584", "ID159661", "", false);
					
	createImageArea(7.5, 24, 39.5, 28.5, "ID159652", "ID159584", "ID159652", "", false);
					
	createImageArea(25.5, 5, 30.5, 20.5, "ID159637", "ID159584", "ID159637", "", false);
					
	createImageArea(7.5, 17.5, 39.5, 21, "ID159649", "ID159584", "ID159649", "", false);
					
	createImageArea(7.5, 13.5, 39.5, 16.5, "ID159646", "ID159584", "ID159646", "", false);
					
	createImageArea(7.5, 4.5, 39.5, 12.5, "ID159643", "ID159584", "ID159643", "", false);
					
	createImageArea(41, 3.245000000000001, 47, 33.495000000000005, "ID159634", "ID159584", "ID159634", "", false);
					
	createImageArea(7, 22.745, 40, 33.495000000000005, "ID159616", "ID159584", "ID159616", "", false);
					
	createImageArea(7, 3.244999999999999, 40, 21.494999999999997, "ID159613", "ID159584", "ID159613", "", false);
					
	createImageArea(0, 3.245000000000001, 6, 33.495000000000005, "ID159628", "ID159584", "ID159628", "", false);
					
	imageMapsReady();
}
			
			ID159586D='<span class=\\\"mov_name\\\">Perform Governance Framework gap analysis</span><span class=\"mov_desc\">In this process gaps in process, IT services and organisational structure against Governance Framework requirements are determined.</span>';				
				ID159589D='<span class=\\\"mov_name\\\">Evaluate Framework implementation scenarios</span><span class=\"mov_desc\">Various scenarios can result both from different variants in Governance Framework requirements (e.g. BASEL II requirements regarding measurement of operational risks) as well as different implementation approach the particular company could select for the same requirement. These scenarios are evaluated in this sub-process.</span>';				
				ID159592D='<span class=\\\"mov_name\\\">Develop projects plans</span><span class=\"mov_desc\">Governance Framework requirements affect different areas of company and are implemented as smaller projects. Plans for these projects (including analysis of dependencies) are developed in this step.</span>';				
				ID159595D='<span class=\\\"mov_name\\\">Execute projects</span><span class=\"mov_desc\">Projects described in the previous step are executed here. If the change in IT service is required, the process moves to the sub-process Design IT service and consequently to the sub-process Develop IT service.</span>';				
				ID159598D='<span class=\\\"mov_name\\\">Design Internal Control System</span><span class=\"mov_desc\">In parallel to Develop project plans, the Internal Control System is designed. </span>';				
				ID159601D='<span class=\\\"mov_name\\\">Test Governance Framework environment</span><span class=\"mov_desc\">After implementation of Governance Framework requirements, the modified processes and IT services should be tested.</span>';				
				ID159604D='<span class=\\\"mov_name\\\">Perform internal/external audit</span><span class=\"mov_desc\">The audit checks alignment of a company with Framework requirements. Depending on Governance Framework, audit can be performed by external institution or using company’s internal resources</span>';				
				ID159610D='<span class=\\\"mov_name\\\">Monitor changes in Governance Frameworks</span><span class=\"mov_desc\">In this process it is checked if Corporate Frameworks regulations changed or new best practice information is available. If yes, it triggers the design phase.</span>';				
				ID159619D='<span class=\\\"mov_name\\\">Execute Internal Control System</span>';				
				ID159622D='<span class=\\\"mov_name\\\">Manage changes in environment</span><span class=\"mov_desc\">Major changes in internal or external environment (e.g. entering new markets, introducing new products, etc.) might also trigger design phase. These changes are monitored here.</span>';				
				ID159625D='<span class=\\\"mov_name\\\">Enterprise Risk Management</span>';				
				ID159631D='<span class=\\\"mov_name\\\">RM Process Overview</span>';				
				ID159655D='<span class=\\\"mov_name\\\">Design IT service</span>';				
				ID159658D='<span class=\\\"mov_name\\\">Develop IT service</span>';				
				ID159664D='<span class=\\\"mov_name\\\">Disclose required information</span>';				
				ID159661D='<span class=\\\"mov_name\\\">Delivery of IT services</span>';				
				ID159613D='<span class=\\\"mov_name\\\">Design</span>';				
				ID159643D='<span class=\\\"mov_name\\\">Design of business processes </span>';				
				ID159646D='<span class=\\\"mov_name\\\">Design of IT services</span>';				
				ID159649D='<span class=\\\"mov_name\\\">Development of IT services</span>';				
				ID159628D='<span class=\\\"mov_name\\\">ERM</span>';				
				ID159616D='<span class=\\\"mov_name\\\">Execution</span>';				
				ID159652D='<span class=\\\"mov_name\\\">Execution of business processes</span>';				
				ID159637D='<span class=\\\"mov_name\\\">ICS design</span>';				
				ID159640D='<span class=\\\"mov_name\\\">ICS execution</span>';				
				ID159634D='<span class=\\\"mov_name\\\">IT RM</span>';				
				
			
function readCM()
{
			ID159586CM = new instCM("Perform Governance Framework gap analysis");
ID159586CM.addAttribute("Referenced process", "mod");
ID159586CM.addLink("Referenced process", "../ID160135/ID160135.html", "Perform Governance Framework gap analysis", "mt_itsp.gif");
ID159589CM = new instCM("Evaluate Framework implementation scenarios");
ID159589CM.addAttribute("Referenced process", "mod");
ID159589CM.addLink("Referenced process", "../ID160296/ID160296.html", "Evaluate Framework implementation scenarios", "mt_itsp.gif");
ID159592CM = new instCM("Develop projects plans");
ID159592CM.addAttribute("Referenced process", "mod");
ID159592CM.addLink("Referenced process", "../ID160356/ID160356.html", "Develop projects plans", "mt_itsp.gif");
ID159595CM = new instCM("Execute projects");
ID159595CM.addAttribute("Referenced process", "mod");
ID159595CM.addLink("Referenced process", "../ID160386/ID160386.html", "Execute projects", "mt_itsp.gif");
ID159598CM = new instCM("Design Internal Control System");
ID159598CM.addAttribute("Referenced process", "mod");
ID159598CM.addLink("Referenced process", "../ID160596/ID160596.html", "Design Internal Control System", "mt_itsa.gif");
ID159601CM = new instCM("Test Governance Framework environment");
ID159601CM.addAttribute("Referenced process", "mod");
ID159601CM.addLink("Referenced process", "../ID161585/ID161585.html", "Test Governance Framework environment", "mt_itsp.gif");
ID159604CM = new instCM("Perform internal/external audit");
ID159604CM.addAttribute("Referenced process", "mod");
ID159604CM.addLink("Referenced process", "../ID161632/ID161632.html", "Perform internal/external audit", "mt_itsp.gif");
ID159610CM = new instCM("Monitor changes in Governance Frameworks");
ID159610CM.addAttribute("Referenced process", "mod");
ID159610CM.addLink("Referenced process", "../ID161471/ID161471.html", "Monitor changes in Governance Frameworks", "mt_itsp.gif");
ID159619CM = new instCM("Execute Internal Control System");
ID159619CM.addAttribute("Referenced process", "mod");
ID159619CM.addLink("Referenced process", "../ID161440/ID161440.html", "Execute Internal Control System", "mt_itsa.gif");
ID159622CM = new instCM("Manage changes in environment");
ID159622CM.addAttribute("Referenced process", "mod");
ID159622CM.addLink("Referenced process", "../ID161522/ID161522.html", "Manage changes in environment", "mt_itsp.gif");
ID159625CM = new instCM("Enterprise Risk Management");
ID159625CM.addAttribute("Referenced process", "mod");
ID159625CM.addLink("Referenced process", "../ID162238/ID162238.html", "Enterprise Risk Management overview", "mt_itsa.gif");
ID159631CM = new instCM("RM Process Overview");
ID159631CM.addAttribute("Referenced process", "mod");
ID159631CM.addLink("Referenced process", "../ID158976/ID158976.html", "IT RM process overview ", "mt_itsa.gif");
ID159655CM = new instCM("Design IT service");
ID159655CM.addAttribute("Referenced process", "mod");
ID159655CM.addLink("Referenced process", "../ID158865/ID158865.html", "Design IT service", "mt_itsp.gif");
ID159658CM = new instCM("Develop IT service");
ID159658CM.addAttribute("Referenced process", "mod");
ID159658CM.addLink("Referenced process", "../ID159562/ID159562.html", "Develop IT service", "mt_itsp.gif");
ID159664CM = new instCM("Disclose required information");
ID159664CM.addAttribute("Referenced process", "mod");
ID159664CM.addLink("Referenced process", "../ID163569/ID163569.html", "Disclose required information", "mt_itsp.gif");
ID159661CM = new instCM("Delivery of IT services");
ID159613CM = new instCM("Design");
ID159643CM = new instCM("Design of business processes ");
ID159646CM = new instCM("Design of IT services");
ID159649CM = new instCM("Development of IT services");
ID159628CM = new instCM("ERM");
ID159616CM = new instCM("Execution");
ID159652CM = new instCM("Execution of business processes");
ID159607CM = new instCM("Free standing note-1");
ID159637CM = new instCM("ICS design");
ID159640CM = new instCM("ICS execution");
ID159634CM = new instCM("IT RM");
ID159667CM = new instCM("");
ID159668CM = new instCM("");
ID159669CM = new instCM("");
ID159670CM = new instCM("");
ID159671CM = new instCM("");
ID159672CM = new instCM("");
ID159673CM = new instCM("");
ID159674CM = new instCM("");
ID159675CM = new instCM("");
ID159676CM = new instCM("");
ID159677CM = new instCM("");
ID159678CM = new instCM("");
ID159679CM = new instCM("");
ID159680CM = new instCM("");
ID159681CM = new instCM("");
ID159682CM = new instCM("");
ID159683CM = new instCM("");
ID159684CM = new instCM("");
ID159685CM = new instCM("");
ID159686CM = new instCM("");
ID159687CM = new instCM("");
ID159688CM = new instCM("");
ID159689CM = new instCM("");
ID159690CM = new instCM("");
ID159691CM = new instCM("");
ID159692CM = new instCM("");
ID159693CM = new instCM("");
ID159694CM = new instCM("");
ID159695CM = new instCM("");
ID159696CM = new instCM("");
ID159697CM = new instCM("");
ID159698CM = new instCM("");
ID159699CM = new instCM("");
ID159700CM = new instCM("");
ID159701CM = new instCM("");
ID159702CM = new instCM("");
ID159703CM = new instCM("");
ID159704CM = new instCM("");
ID159705CM = new instCM("");
ID159706CM = new instCM("");
ID159707CM = new instCM("");
ID159708CM = new instCM("");
ID159709CM = new instCM("");
ID159710CM = new instCM("");
ID159711CM = new instCM("");
ID159712CM = new instCM("");
ID159713CM = new instCM("");
ID159714CM = new instCM("");
ID159715CM = new instCM("");
ID159716CM = new instCM("");
ID171071CM = new instCM("");
}
		